@@ -4,7 +4,6 @@
 from mcpi.vec3 import Vec3
 
 from .thing import Thing
-from .scene import Scene
 
 
 class Blocks(Thing):
@@ -12,10 +11,8 @@ class Blocks(Thing):
     height = 2  # y
     length = 4  # z
 
-    def build(self):
+    def create(self):
         p = self.position
-        Scene.server.setBlocks(p.x, p.y, p.z,
-                               p.x + self.width - 1, p.y + self.height - 1, p.z + self.length - 1,
-                               self.block)
-
         self._end_position = Vec3(p.x + self.width - 1, p.y + self.height - 1, p.z + self.length - 1)
+        # self.set_blocks(Vec3(p.x, p.y, p.z), self._end_position, self.block.id)
+        self.set_blocks(self._end_position, Vec3(p.x, p.y, p.z), self.block.id)
